@@ -3,6 +3,7 @@ import sys
 import time
 import shutil
 import pathlib
+import imp
 from yaplee.server import Server
 from distutils.dir_util import copy_tree
 import subprocess
@@ -47,33 +48,38 @@ class AppStarter:
     def ScanApplication(self):
         for page_r, page_d, page_f in os.walk(os.path.join(self.user_path), 'pages'):
             for page in page_d:
-                for r,d,f in os.walk(os.path.join(self.user_path, 'pages', str(page))):
-                    if(r == os.path.join(self.user_path, 'pages', str(page))):
-                        for TAF in self.__TRUE_PAGE_FOLDERS:
-                            if(TAF not in d):
-                                self.__DAMAGED_APPS.append(page); self.__ERRORS += 1
-                                continue
-                            else:
-                                if(page not in self.__LOADED_PAGES):
-                                    self.__LOADED_PAGES.append(page)
-                    
-                        for TAF in self.__TRUE_PAGE_FILES:
-                            if(TAF not in f and page not in self.__DAMAGED_APPS):
-                                self.__DAMAGED_APPS.append(page); self.__ERRORS += 1
-                                continue
-                            else:
-                                if(page not in self.__LOADED_PAGES):
-                                    self.__LOADED_PAGES.append(page)
+                if(page in self.GetApplicationConfig()['APP_PAGES']):
+                    for r,d,f in os.walk(os.path.join(self.user_path, 'pages', str(page))):
+                        if(r == os.path.join(self.user_path, 'pages', str(page))):
+                            for TAF in self.__TRUE_PAGE_FOLDERS:
+                                if(TAF not in d):
+                                    self.__DAMAGED_APPS.append(page); self.__ERRORS += 1
+                                    continue
+                                else:
+                                    if(page not in self.__LOADED_PAGES):
+                                        self.__LOADED_PAGES.append(page)
+                        
+                            for TAF in self.__TRUE_PAGE_FILES:
+                                if(TAF not in f and page not in self.__DAMAGED_APPS):
+                                    self.__DAMAGED_APPS.append(page); self.__ERRORS += 1
+                                    continue
+                                else:
+                                    if(page not in self.__LOADED_PAGES):
+                                        self.__LOADED_PAGES.append(page)
                 
         if(len(self.__DAMAGED_APPS) > 2):
             self.not_loaded_pages = str(', '.join(self.__DAMAGED_APPS[:2]))+' and '+str(len(self.__DAMAGED_APPS)-2)+' more pages'
         else:
             self.not_loaded_pages = str(', '.join(self.__DAMAGED_APPS))
+    
+    def GetApplicationConfig(self):
+        config = imp.load_source('application.config', os.path.join(self.user_path, 'config.py'))
+        return_it = {'APP_PAGES':config.APP_PAGES, 'DEVELOPMENT_SERVER_PORT':config.DEVELOPMENT_SERVER_PORT}
+        return return_it
 
     def Load_Controllers(self, page, server_path):
-        sys.path.append(os.path.join(self.user_path, 'pages', page))
         try:
-            import config
+            config = imp.load_source('page.config', os.path.join(self.user_path, 'pages', page, 'config.py'))
             app = config.page
             for key, value in app.GetRegisterList().items():
                 for i in value:
@@ -114,12 +120,15 @@ class AppStarter:
             str(self.__ERRORS)+' errors were found in the application, ('+str(self.not_loaded_pages)+') were not loaded.'
         )
         print('Note: Use CTRL+C to quit development server')
-        server = Server()
+        server = Server(int(self.GetApplicationConfig()['DEVELOPMENT_SERVER_PORT']))
         try:
             server.CheckSystem()
+            if(self.__LOADED_PAGES == []):
+                print('There is no page to run! Stopping WebServer...')
+                sys.exit()
             for page in self.__LOADED_PAGES:
                 self.Load_Controllers(page, server.server_foldername)
-            subprocess.run('python -m http.server 8891 --bind 127.0.0.1 --directory "'+str(os.path.join(self.user_path, 'pages', '.server'))+'"')
+            subprocess.run('python -m http.server '+str(self.GetApplicationConfig()['DEVELOPMENT_SERVER_PORT'])+' --bind 127.0.0.1 --directory "'+str(os.path.join(self.user_path, 'pages', '.server'))+'"')
         except KeyboardInterrupt:
             server.Stop()
             
